//******************************************************************************
//  Interrupt durch Pegelnderung an Port 2.0 / 2.1
//  (c) 2005 M. Buccini / M. Buecker
//  vgl. fet110_P2_int.c in slac011e.zip
//
//  Eine an P1.0 angeschlossene LED wird durch eine negative Flanke an P2.0
//  angeschaltet und durch eine positive Flanke an P2.1 wieder ausgeschaltet.
//  P2.0 ist ber einen Pull-Up-Widerstand an Vcc, P2.1 ber einen Pull-Down-
//  Widerstand an Masse angeschlossen.
//
//                MSP430F1232
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-               /|\
//            |                 |        ___      |
//            |             P2.0|---o---|___|-----o
//            |                 |   |       100k  |
//     LED<---|P1.0             |   |____/_____   |
//            |                 |        ___   |  |
//            |             P2.1|---o---|___|--o  |
//            |                 |   |  100k   _|_ |
//            |                 |   |____/________|
//             
//******************************************************************************

#include  <msp430x12x2.h>

void main()
{
  WDTCTL = WDTPW + WDTHOLD;                 // WDT anhalten; Passwort bentigt
  P1DIR = BIT0;                             // P1.0 als Ausgang benutzen
  P2IES = BIT1;                             // Flankenerkennung: P2.1: neg->pos, sonst pos->neg.
  P2IE |= BIT0 + BIT1;                      // Interrupt erlauben fr P2.0,1

  _BIS_SR(LPM3_bits + GIE);                 // In den LPM3 eintreten (Interrupts erlauben)

  for (;;)                                  // Endlosschleife [== while (1) ]
  {  
  }
}


#pragma vector=PORT2_VECTOR                 // PORT_2 Interrupt Service Routine (ISR)
__interrupt void PORT2_ISR (void)
{
  if (P2IFG & BIT0) P1OUT |= BIT0;          // Falls P2.0 pos->neg setze P1.0
  if (P2IFG & BIT1) P1OUT &= ~BIT0;         // Falls P2.1 neg->pos lsche P1.0
  P2IFG = 0x00;                             // Interrupt Flags lschen
}
