//******************************************************************************
//  Timer A: Blink-Schaltung
//  (c) 2005 M. Buccini / M. Buecker
//  vgl. fet120_ta_01.c in slac013d.zip
//
//  Eine an P1.0 angeschlossene LED blinkt mit einer Dauer von 50.000 SMCLKs.
//  Ein berlauf im CCR0-Zhlregister erzeugt einen Interrupt. In der ISR wird
//  die LED dann umgeschaltet.
//
//               MSP430F1232
//            -----------------
//        /|\|              XIN|-
//         | |                 |
//         --|RST          XOUT|-
//           |                 |
//           |             P1.0|-->LED
//
//******************************************************************************

#include  <msp430x12x2.h>

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // WDT anhalten; Passwort bentigt
  P1DIR |= 0x01;                            // P1.0 als Ausgang benutzen
  CCTL0 = CCIE;                             // CCR0 (Zhlregister) Interrupt erlaubt
  CCR0 = 50000;                             // Interrupt bei CCR0 = 50.000 geben
  TACTL = TASSEL_2 + MC_2;                  // Timer-Takt ist SMCLK; Starte Timer im Cont. Mode

  _BIS_SR(LPM0_bits + GIE);                 // In den LPM0 eintreten (Interrupts erlauben)
}


#pragma vector=TIMERA0_VECTOR               // Timer_A ISR
__interrupt void Timer_A (void)
{
  P1OUT ^= 0x01;                            // P1.0 durch XOR umschalten
  CCR0 += 50000;                            // Offset zu CCR0 addieren
}

