//******************************************************************************
//  ADC 10: Schwellwert-Messung
//  (c) 2005 M. Buccini / M. Buecker
//  vgl. fet120_adc10_01.c in slac013d.zip
//
//  Ein an den Eingang A0 (P2.0) angeschlossener Spannungsteiler liefert eine
//  variable Eingangsspannung im Bereich von 0V ... Vcc, die der ADC10 in einen
//  Integerwert zwischen 0 und 1023 umwandelt. Steigt der Wert ber Vcc/2, also
//  ist der gewandelte Wert >=512, wird P1.0 gesetzt, ansonsten gelscht. Eine
//  an P1.0 angeschlossene LED leuchtet also, wenn Vcc/2 berschritten wurde.
//
//                MSP430F1232
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//  (0..Vcc)->|A0 (P2.0)    P1.0|-->LED
//
//******************************************************************************

#include  <msp430x12x2.h>

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // WDT anhalten; Passwort bentigt
  ADC10CTL0 = ADC10SHT_2 + ADC10IE;         // S&H-Zeit; ADC10 Interrupt erlauben
  ADC10CTL0 = ADC10ON;                      // ADC10 aktivieren
  ADC10AE |= 0x01;                          // P2.0 als ADC-Eingang benutzen
  P1DIR |= 0x01;                            // P1.0 als Ausgang benutzen

  for (;;)
  {
    ADC10CTL0 |= ENC + ADC10SC;             // Sampling starten
    _BIS_SR(CPUOFF + GIE);                  // In den LPM0 eintreten (Interrupts erlauben)
    if (ADC10MEM < 0x200)                   // Falls ADC10MEM < 200h (==512)...
      P1OUT &= ~0x01;                       // ...lsche P1.0
    else                                    // ansonsten:
      P1OUT |= 0x01;                        // ...setze P1.0
  }
}


#pragma vector=ADC10_VECTOR                 // ADC10 ISR
__interrupt void ADC10_ISR (void)
{
    _BIC_SR_IRQ(CPUOFF);                    // Lsche CPUOFF Bit in 0(SR) (aktuelles Statusregister)
}
