//******************************************************************************
//  UART0: Bidirektionale Kommunikation
//  (c) 2005 M. Buccini / M. Buecker
//  vgl. fet120_uart06_09600.c in slac013d.zip
//
//  Die Pins P3.4 und P3.5 werden als Ein- bzw. Ausgang der internen seriellen 
//  Schnittstelle UART0 genutzt. Zur Kommunikation wird ein Terminalprogramm auf
//  einem PC gestartet und mit dem MSP430 ber eine COM-Schnittstelle verbunden.
//  Folgende Sendeparameter werden eingestellt: 9600 Baud, 8 Bits, kein Parity,
//  1 Stoppbit. Empfngt der MSP430 ein 'u', sendet er den String "Hello World"
//  zurck. Dazu wird sukzessive durch den Interrupt nach Aussenden eines Bytes
//  ein weiteres Byte des Strings in den Sendepuffer geschoben.
//
//               MSP430F1232
//            -----------------
//        /|\|              XIN|-
//         | |                 | 32kHz
//         --|RST          XOUT|-
//           |                 |
//           |             P3.4|----------->    ----
//           |                 | 9600 - 8N1    | PC |
//           |             P3.5|<-----------    ----
//
//******************************************************************************

#include  <msp430x12x2.h>

static char string1[] = { "Hello World\r\n" };  // String erzeugen

char i;

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // WDT anhalten; Passwort bentigt
  P3SEL = 0x30;                             // P3.4,5 als USART0 TXD/RXD benutzen

  ME2 |= UTXE0 + URXE0;                     // USART0 TXD/RXD aktivieren
  UCTL0 |= CHAR;                            // 8 Bit Datenbytes
  UTCTL0 |= SSEL0;                          // UCLK = ACLK
  UBR00 = 0x03;                             // Baudrate einstellen: Teiler fr...
  UBR10 = 0x00;                             // ... ~9600Baud aus 32.768 Hz...
  UMCTL0 = 0x4A;                            // ... mit Modulation auf =9600Baud
  UCTL0 &= ~SWRST;                          // Initialisiere USART State Machine
  IE2 |= URXIE0 + UTXIE0;                   // Erlaube USART0 RX/TX Interrupt
  IFG2 &= ~UTXIFG0;                         // Lsche Initialflag (vom POR)

  _BIS_SR(LPM3_bits + GIE);                 // In den LPM3 eintreten (Interrupts erlauben)
}


#pragma vector=UART0TX_VECTOR               // UART0 TX ISR
__interrupt void usart0_tx (void)
{
  if (i < sizeof string1-1)                 // Falls String  noch nicht komplett gesendet...
    TXBUF0 = string1[i++];                  // ...schiebe weiteres Byte in den Sendepuffer
}

#pragma vector=UART0RX_VECTOR               // UART0 RX ISR
__interrupt void usart0_rx (void)
{
  if (RXBUF0 == 'u')                        // Falls 'u' empfangen...
  {
    i = 0;
    TXBUF0 = string1[i++];                  // ...schiebe erstes Byte des Strings in den Sendepuffer
  }
}
