//******************************************************************************
//  SPI: Ansteuerung eines LCD
//  (c) 2006 C. Gruenbaum / M. Buecker
//  vgl. fet120_spi0_mstr.c in slac013d.zip
//
//  Ein LCD wird ber die SPI-Schnittstelle angesteuert. Dazu werden nur 3 Pins
//  bentigt, um die Daten (SI), den Bustakt (CLK) und ein Steuersignal (RS) zu
//  bertragen. Das LCD wird in diesem Beispiel an 3,3V betrieben.
//
//                MSP430F1232
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-              LCD  EA DOG-M
//            |                 |            --------------------
//            |             P3.1|--> SI  -->| D7             VDD |<---o 3,3V
//            |             P3.3|--> CLK -->| D6                 |
//            |             P3.5|--> RS  -->| RS             CSB |----| GND
//
//******************************************************************************

#include  <msp430x12x2.h>

void delay(unsigned int time)
{
  for (; time > 0;time--)                   // Warte Vielfaches von 30s
  {
    int i;
    i = 7;
    do (i--);                               // Wartezeit durch Schleife etwa 30s
    while (i != 0);
  }
}

void ausgabe(int rs, char zeichen)
{
  if (rs)
    P3OUT |= 0x20;                          // Setze P3.5 (RS=1 >> Daten senden)
  else
    P3OUT &= 0xDE;                          // Lsche P3.5 (RS=0 >> Befehl senden)
  TXBUF0 = zeichen;
  delay(2);
}

void initial(void)                          // Display Initialisierung (vgl. Datenblatt)
{
  delay(2000);                              // Warte ~60ms
  ausgabe(0,0x39);                          // Modus: 8 Bit, 2 Zeilen, Tabelle 1
  ausgabe(0,0x14);                          // Setze Bias (1/5)
  ausgabe(0,0x78);                          // Kontrast einstellen (LByte)
  ausgabe(0,0x55);                          // Internen DC/DC-Wandler einschalten / Kontrast (HByte)
  ausgabe(0,0x6D);                          // Spannungsverstrker steuern
  delay(10000);                             // Warte ~300ms
  ausgabe(0,0x0C);                          // Display anschalten
  ausgabe(0,0x01);                          // Display lschen
  delay(100);                               // Warte ~3ms
  ausgabe(0,0x06);                          // Allg. Cursorbewegung (nach rechts)
}

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // WDT anhalten; Passwort bentigt
  P3SEL = 0x0E;                             // Port 3 fr SPI verwenden
  P3DIR |= 0x20;                            // P3.5 als Ausgang fr RS benutzen
  U0CTL = CHAR + SYNC + MM + SWRST;         // SPI-Modus (8-bit, Master)
  U0TCTL = CKPL + SSEL1 + STC;              //           (polarity, SMCLK, 3-wire)
  U0BR0 = 0x02;                             // SPICLK = SMCLK/2
  U0BR1 = 0x00;
  U0MCTL = 0x00;
  ME2 = USPIE0;                             // Modul aktivieren
  U0CTL &= ~SWRST;                          // SPI aktivieren

  initial();

  ausgabe(1,'H');
  ausgabe(1,'a');
  ausgabe(1,'l');
  ausgabe(1,'l');
  ausgabe(1,'o');
  ausgabe(1,' ');
  ausgabe(1,'W');
  ausgabe(1,'e');
  ausgabe(1,'l');
  ausgabe(1,'t');
  ausgabe(1,'!');

  while(1) {};
}